@@ -29,9 +29,11 @@ import {
   getSharedPlacementRuleWarning,
   getSharedSubscriptionWarning
 } from './utils'
-import { getSourcePath } from '../../TemplateEditor/utils/utils'
+import { getSourcePath } from 'temptifly'
+import apolloClient from '../../../../lib/client/apollo-client'
 import _ from 'lodash'
 import msgs from '../../../../nls/platform.properties'
+import { SEARCH_QUERY } from '../../../apollo-client/queries/SearchQueries'
 
 const existingRuleCheckbox = 'existingrule-checkbox'
 const localClusterCheckbox = 'local-cluster-checkbox'
@@ -95,6 +97,7 @@ export const updateDisplayForPlacementControls = (
       _.set(localClusterControl, 'type', 'hidden')
     } else {
       _.set(existingRuleControl, 'type', 'hidden')
+      _.set(existingRuleControl, 'active', '')
       selectedRuleNameControl && _.set(selectedRuleNameControl, 'active', '')
 
       _.set(onlineControl, 'type', 'checkbox')
@@ -106,14 +109,17 @@ export const updateDisplayForPlacementControls = (
     //reset all values
     _.set(localClusterControl, 'active', false)
     _.set(onlineControl, 'active', false)
-    clusterSelectorControl.active.clusterLabelsListID = 1
-    delete clusterSelectorControl.active.clusterLabelsList
-    clusterSelectorControl.active.clusterLabelsList = [
-      { id: 0, labelName: '', labelValue: '', validValue: false }
-    ]
-    clusterSelectorControl.active.mode = true
-    delete clusterSelectorControl.showData
+    if (clusterSelectorControl.active) {
+      clusterSelectorControl.active.clusterLabelsListID = 1
+      delete clusterSelectorControl.active.clusterLabelsList
+      clusterSelectorControl.active.clusterLabelsList = [
+        { id: 0, labelName: '', labelValue: '', validValue: false }
+      ]
+      clusterSelectorControl.active.mode = true
+      delete clusterSelectorControl.showData
+    }
   })
+  return controlGlobal
 }
 
 export const updatePlacementControlsForLocal = placementControl => {
@@ -127,8 +133,15 @@ export const updatePlacementControlsForLocal = placementControl => {
   )
 
   if (active === true) {
-    onlineControl && _.set(onlineControl, 'type', 'hidden')
-    clusterSelectorControl && _.set(clusterSelectorControl, 'type', 'hidden')
+    if (onlineControl) {
+      _.set(onlineControl, 'type', 'hidden')
+      _.set(onlineControl, 'active', false)
+    }
+    if (clusterSelectorControl) {
+      _.set(clusterSelectorControl, 'type', 'hidden')
+      clusterSelectorControl.active &&
+        _.set(clusterSelectorControl.active, 'mode', false)
+    }
   } else {
     if (onlineControl) {
       _.set(onlineControl, 'type', 'checkbox')
@@ -155,9 +168,10 @@ export const updatePlacementControlsForCustom = placementControl => {
     ({ id }) => id === localClusterCheckbox
   )
 
+  localControl && _.set(localControl, 'active', false)
+
   if (active && active.mode) {
     onlineControl && _.set(onlineControl, 'active', false)
-    localControl && _.set(localControl, 'active', false)
   } else {
     onlineControl && _.set(onlineControl, 'active', true)
   }
@@ -175,10 +189,11 @@ export const updatePlacementControlsForAllOnline = placementControl => {
     ({ id }) => id === localClusterCheckbox
   )
 
+  localControl && _.set(localControl, 'active', false)
+
   if (clusterSelectorControl && clusterSelectorControl.active) {
     if (active) {
       _.set(clusterSelectorControl.active, 'mode', false)
-      localControl && _.set(localControl, 'active', false)
     } else {
       _.set(clusterSelectorControl.active, 'mode', true)
     }
@@ -187,6 +202,26 @@ export const updatePlacementControlsForAllOnline = placementControl => {
   return groupControlData
 }
 
+//when loading an existing app, pass to the control the placement value that is currently stored by the app
+//the reverse() function retrieves this the value out of the existing app template
+//the editor needs the existing value to know whether or not the user changed that value
+export const reverseExistingRule = (control, templateObject) => {
+  const active = _.get(
+    templateObject,
+    getSourcePath('Subscription[0].spec.placement.placementRef.name')
+  )
+  if (active && control.active === undefined) {
+    control.active = active.$v
+
+    const { groupControlData } = control
+    const selectedRuleName = groupControlData.find(
+      ({ id }) => id === 'selectedRuleName'
+    )
+    selectedRuleName.active = active.$v
+  }
+  return control
+}
+
 export const reverseOnline = (control, templateObject) => {
   const active = _.get(
     templateObject,
@@ -217,7 +252,36 @@ export const summarizeOnline = (control, globalControlData, summary) => {
   }
 }
 
-const placementData = [
+const getGeneralQuery = (kind, name) => {
+  return {
+    filters: [
+      { property: 'kind', values: [kind] },
+      { property: 'name', values: [name] }
+    ]
+  }
+}
+
+const queryReturnsItems = (kind, name) => {
+  const query = getGeneralQuery(kind, name)
+  return apolloClient
+    .search(SEARCH_QUERY, { input: [query] })
+    .then(response => {
+      const itemRes =
+        response &&
+        response.data &&
+        response.data.searchResult[0] &&
+        response.data.searchResult[0].items
+      return !!itemRes && !!itemRes.length
+    })
+    .catch(() => {
+      // default to have the local-cluster managed
+      return true
+    })
+}
+
+const enableHubSelfManagement = queryReturnsItems('cluster', 'local-cluster')
+
+const placementData = async () => [
   ////////////////////////////////////////////////////////////////////////////////////
   ///////////////////////  clusters  /////////////////////////////////////
   {
@@ -241,10 +305,12 @@ const placementData = [
     validation: {}
   },
   {
-    name: 'creation.app.exitingRuleCombo',
-    tooltip: 'tooltip.creation.app.exitingRuleCombo',
+    name: 'creation.app.existingRuleCombo',
+    tooltip: 'tooltip.creation.app.existingRuleCombo',
     id: 'placementrulecombo',
     type: 'hidden',
+    placeholder: 'select.existing.placement.rule',
+    reverse: reverseExistingRule,
     fetchAvailable: loadExistingPlacementRules(),
     onSelect: updateNewRuleControls,
     validation: {}
@@ -266,8 +332,12 @@ const placementData = [
   {
     id: 'online-cluster-only-checkbox',
     type: 'checkbox',
-    name: 'creation.app.settings.onlineClusters',
-    tooltip: 'tooltip.creation.app.settings.onlineClusters',
+    name: (await enableHubSelfManagement)
+      ? 'creation.app.settings.onlineClusters'
+      : 'creation.app.settings.onlineClustersOnly',
+    tooltip: (await enableHubSelfManagement)
+      ? 'tooltip.creation.app.settings.onlineClusters'
+      : 'tooltip.creation.app.settings.onlineClustersOnly',
     active: false,
     available: [],
     onSelect: updatePlacementControlsForAllOnline,
@@ -276,7 +346,7 @@ const placementData = [
   },
   {
     id: localClusterCheckbox,
-    type: 'checkbox',
+    type: (await enableHubSelfManagement) ? 'checkbox' : 'hidden',
     name: 'creation.app.settings.localClusters',
     tooltip: 'tooltip.creation.app.settings.localClusters',
     onSelect: updatePlacementControlsForLocal,
