@@ -15,6 +15,21 @@ import _ from 'lodash'
 import moment from 'moment'
 import msgs from '../../../../nls/platform.properties'
 import { LOCAL_HUB_NAME } from '../../../../lib/shared/constants'
+import {
+  isDeployableResource,
+  nodeMustHavePods,
+  getClusterName,
+  getRouteNameWithoutIngressHash,
+  getActiveFilterCodes,
+  filterSubscriptionObject,
+  getOnlineClusters,
+  getClusterHost,
+  getPulseStatusForSubscription,
+  getExistingResourceMapKey,
+  syncControllerRevisionPodStatusMap,
+  fixMissingStateOptions
+} from './diagram-helpers-utils'
+import { getEditLink } from '../../../../lib/client/resource-helper'
 
 const metadataName = 'specs.raw.metadata.name'
 const metadataNamespace = 'specs.raw.metadata.namespace'
@@ -28,12 +43,18 @@ const specsPropsYaml = 'props.show.yaml'
 const showLocalYaml = 'props.show.local.yaml'
 const showResourceYaml = 'show_resource_yaml'
 const specLocation = 'raw.spec.host.location'
-
+const clusterObjsPath = 'clusters.specs.clusters'
+const checkmarkStatus = 'checkmark'
+const warningStatus = 'warning'
+const pendingStatus = 'pending'
+const failureStatus = 'failure'
+const checkmarkCode = 3
+const warningCode = 2
+const pendingCode = 1
+const failureCode = 0
 //pod state contains any of these strings
 const podErrorStates = ['err', 'off', 'invalid', 'kill']
-
-const podWarningStates = ['pending', 'creating']
-
+const podWarningStates = [pendingStatus, 'creating']
 const podSuccessStates = ['run']
 
 import {
@@ -70,21 +91,6 @@ export const addDetails = (details, dets) => {
   })
 }
 
-export const getClusterName = nodeId => {
-  if (nodeId === undefined) {
-    return ''
-  }
-  const clusterIndex = nodeId.indexOf('--clusters--')
-  if (clusterIndex !== -1) {
-    const startPos = nodeId.indexOf('--clusters--') + 12
-    const endPos = nodeId.indexOf('--', startPos)
-    return nodeId.slice(startPos, endPos)
-  }
-
-  //node must be deployed locally on hub, such as ansible jobs
-  return LOCAL_HUB_NAME
-}
-
 export const getWrappedNodeLabel = (label, width, rows = 3) => {
   // if too long, add elipse and split the rest
   const ip = /\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}$/.exec(label)
@@ -252,87 +258,6 @@ export const addPropertyToList = (list, data) => {
   return list
 }
 
-export const nodeMustHavePods = node => {
-  //returns true if the node should deploy pods
-
-  if (
-    !node ||
-    !node.type ||
-    R.contains(node.type, ['application', 'placements', 'subscription'])
-  ) {
-    return false
-  }
-
-  if (
-    R.contains(R.pathOr('', ['type'])(node), [
-      'pod',
-      'replicaset',
-      'daemonset',
-      'statefulset',
-      'replicationcontroller',
-      'deployment',
-      'deploymentconfig'
-    ])
-  ) {
-    //pod deployables must have pods
-    return true
-  }
-  const hasContainers =
-    R.pathOr([], ['specs', 'raw', 'spec', 'template', 'spec', 'containers'])(
-      node
-    ).length > 0
-  const hasReplicas = R.pathOr(undefined, ['specs', 'raw', 'spec', 'replicas'])(
-    node
-  ) //pods will go under replica object
-  const hasDesired = R.pathOr(undefined, ['specs', 'raw', 'spec', 'desired'])(
-    node
-  ) //deployables from subscription package have this set only, not containers
-  if ((hasContainers || hasDesired) && !hasReplicas) {
-    return true
-  }
-
-  if (hasReplicas) {
-    return true
-  }
-
-  return false
-}
-
-export const getPulseStatusForSubscription = node => {
-  let pulse = 'green'
-
-  const resourceMap = _.get(node, `specs.${node.type}Model`)
-  if (!resourceMap) {
-    pulse = 'orange' //resource not available
-    return pulse
-  }
-
-  let isPlaced = false
-  Object.values(resourceMap).forEach(subscriptionItem => {
-    if (subscriptionItem.status) {
-      if (R.contains('Failed', subscriptionItem.status)) {
-        pulse = 'red'
-      }
-      if (subscriptionItem.status === 'Subscribed') {
-        isPlaced = true // at least one cluster placed
-      }
-
-      if (
-        subscriptionItem.status !== 'Subscribed' &&
-        subscriptionItem.status !== 'Propagated' &&
-        pulse !== 'red'
-      ) {
-        pulse = 'yellow' // anything but failed or subscribed
-      }
-    }
-  })
-  if (pulse === 'green' && !isPlaced) {
-    pulse = 'yellow' // set to yellow if not placed
-  }
-
-  return pulse
-}
-
 export const getPulseStatusForCluster = node => {
   const clusters = _.get(node, 'specs.clusters')
   let okCount = 0,
@@ -374,14 +299,15 @@ const getPulseStatusForGenericNode = node => {
   }
   const name = _.get(node, metadataName, '')
   const channel = _.get(node, 'specs.raw.spec.channel', '')
-  const resourceName = channel.length > 0 ? `${channel}-${name}` : name
+  const resourceName =
+    !isDeployableResource(node) && channel.length > 0
+      ? `${channel}-${name}`
+      : name
 
   const resourceMap = _.get(node, `specs.${node.type}Model`)
   const clusterNames = R.split(',', getClusterName(node.id))
-  const onlineClusters = getOnlineClusters(
-    clusterNames,
-    node.clusters.specs.clusters
-  )
+  const clusterObjs = _.get(node, clusterObjsPath, [])
+  const onlineClusters = getOnlineClusters(clusterNames, clusterObjs)
   if (!resourceMap || onlineClusters.length === 0) {
     pulse = 'orange' //resource not available
     return pulse
@@ -466,12 +392,20 @@ export const getPulseForNodeWithPodStatus = node => {
   if (node.type === 'pod') {
     desired = 1
   }
+  if (
+    node.type === 'controllerrevision' &&
+    resourceMap &&
+    Object.keys(resourceMap).length > 0
+  ) {
+    desired = resourceMap[Object.keys(resourceMap)[0]].desired
+      ? resourceMap[Object.keys(resourceMap)[0]].desired
+      : 'NA'
+  }
+
   const resourceName = _.get(node, metadataName, '')
   const clusterNames = R.split(',', getClusterName(node.id))
-  const onlineClusters = getOnlineClusters(
-    clusterNames,
-    node.clusters.specs.clusters
-  )
+  const clusterObjs = _.get(node, clusterObjsPath, [])
+  const onlineClusters = getOnlineClusters(clusterNames, clusterObjs)
 
   if (!resourceMap || onlineClusters.length === 0) {
     pulse = 'orange' //resource not available
@@ -486,7 +420,9 @@ export const getPulseForNodeWithPodStatus = node => {
   clusterNames.forEach(clusterName => {
     clusterName = R.trim(clusterName)
 
-    const resourceItem = resourceMap[`${resourceName}-${clusterName}`]
+    const resourceItem = fixMissingStateOptions(
+      resourceMap[`${resourceName}-${clusterName}`]
+    )
     const processItem = Object.keys(podList).length === 0 && resourceItem
 
     if (resourceItem && resourceItem.kind === 'daemonset') {
@@ -575,20 +511,29 @@ export const computeNodeStatus = node => {
     return pulse
   }
 
+  const isDeployable = isDeployableResource(node)
   switch (node.type) {
   case 'application':
-    if (!_.get(node, 'specs.channels')) {
+    if (isDeployable) {
+      pulse = getPulseStatusForGenericNode(node)
+    } else if (!_.get(node, 'specs.channels')) {
       pulse = 'red'
     }
     break
   case 'placements':
-    if (!_.get(node, 'specs.raw.status.decisions')) {
+    if (isDeployable) {
+      pulse = getPulseStatusForGenericNode(node)
+    } else if (!_.get(node, 'specs.raw.status.decisions')) {
       pulse = 'red'
     }
     break
   case 'subscription':
-    pulse = getPulseStatusForSubscription(node)
-    shapeType = getShapeTypeForSubscription(node)
+    if (isDeployable) {
+      pulse = getPulseStatusForGenericNode(node)
+    } else {
+      pulse = getPulseStatusForSubscription(node)
+      shapeType = getShapeTypeForSubscription(node)
+    }
     break
   case 'cluster':
     pulse = getPulseStatusForCluster(node)
@@ -602,6 +547,26 @@ export const computeNodeStatus = node => {
   return pulse
 }
 
+export const createEditLink = node => {
+  const kind = _.get(node, 'specs.raw.kind') || _.get(node, 'kind')
+  const apigroup = _.get(node, 'apigroup')
+  const apiversion = _.get(node, 'apiversion')
+  const cluster = _.get(node, 'cluster')
+  let apiVersion = _.get(node, 'specs.raw.apiVersion')
+  if (!apiVersion) {
+    apiVersion =
+      apigroup && apiversion ? apigroup + '/' + apiversion : apiversion
+  }
+
+  return getEditLink({
+    name: _.get(node, 'name'),
+    namespace: _.get(node, 'namespace'),
+    kind: kind ? kind.toLowerCase() : undefined,
+    apiVersion,
+    cluster: cluster ? cluster : undefined
+  })
+}
+
 export const createDeployableYamlLink = (node, details) => {
   //returns yaml for the deployable
   if (
@@ -611,10 +576,11 @@ export const createDeployableYamlLink = (node, details) => {
       'application',
       'placements',
       'subscription'
-    ])
+    ]) &&
+    node.specs.isDesign // only for top-level resources
   ) {
-    const selfLink = _.get(node, 'specs.raw.metadata.selfLink')
-    selfLink &&
+    const editLink = createEditLink(node)
+    editLink &&
       details.push({
         type: 'link',
         value: {
@@ -622,7 +588,7 @@ export const createDeployableYamlLink = (node, details) => {
           data: {
             action: showResourceYaml,
             cluster: LOCAL_HUB_NAME,
-            selfLink: selfLink
+            editLink: editLink
           }
         }
       })
@@ -669,70 +635,22 @@ export const getPercentage = (value, total) => {
 }
 
 export const setClusterStatus = (node, details) => {
+  const { id } = node
   const specs = _.get(node, 'specs', {})
   const { cluster, clusters = [] } = specs
   const clusterArr = cluster ? [cluster] : clusters
 
-  if (clusterArr.length > 1) {
-    addPropertyToList(
-      details,
-      getNodePropery(node, ['specs', 'clusterNames'], 'resource.clusters')
-    )
+  details.push({
+    type: 'label',
+    labelValue: `Clusters (${clusterArr.length})`
+  })
 
-    details.push({
-      type: 'spacer'
-    })
-  }
-
-  clusterArr.forEach(c => {
-    const {
-      metadata = {},
-      capacity = {},
-      allocatable = {},
-      clusterip,
-      status
-    } = c
-    const { name, namespace, creationTimestamp } = metadata
-    //void ({ labels } = metadata)
-    const { nodes, cpu: cc, memory: cm } = capacity
-    const { pods, cpu: ac, memory: am } = allocatable
-    details.push({ labelKey: 'resource.name', value: name })
-    details.push({ labelKey: 'resource.namespace', value: namespace })
-    if (c.consoleURL) {
-      const href = c.consoleURL
-      details.push({
-        type: 'link',
-        value: {
-          label: msgs.get('details.cluster.console'),
-          id: `${href}-location`,
-          data: {
-            action: 'open_link',
-            targetLink: href
-          }
-        },
-        indent: true
-      })
+  details.push({
+    type: 'clusterdetailcombobox',
+    comboboxdata: {
+      clusterList: clusterArr,
+      clusterID: id
     }
-
-    // general details
-    addDetails(details, [
-      { labelKey: 'resource.clusterip', value: clusterip },
-      { labelKey: 'resource.pods', value: pods },
-      { labelKey: 'resource.nodes', value: nodes },
-      { labelKey: 'resource.status', value: status },
-      {
-        labelKey: 'resource.cpu',
-        value: `${getPercentage(inflateKubeValue(ac), inflateKubeValue(cc))}%`
-      },
-      {
-        labelKey: 'resource.memory',
-        value: `${getPercentage(inflateKubeValue(am), inflateKubeValue(cm))}%`
-      },
-      { labelKey: 'resource.created', value: getAge(creationTimestamp) }
-    ])
-    details.push({
-      type: 'spacer'
-    })
   })
 
   return details
@@ -826,22 +744,25 @@ export const getNameWithoutChartRelease = (
   const savedName = name
   const labelAttr = _.get(relatedKind, 'label', '')
   const labels = _.split(labelAttr, ';')
+  const labelMap = {}
   let foundReleaseLabel = false
   labels.forEach(label => {
     const splitLabelContent = _.split(label, '=')
-    if (
-      splitLabelContent.length === 2 &&
-      _.trim(splitLabelContent[0]) === 'release'
-    ) {
-      //get label for release name
-      foundReleaseLabel = true
-      const releaseName = _.trim(splitLabelContent[1])
-      name = _.replace(name, `${releaseName}-`, '')
-      name = _.replace(name, releaseName, '')
 
-      if (name.length === 0) {
-        // release name is used as name, need to strip generated suffix
-        name = removeReleaseGeneratedSuffix(savedName)
+    if (splitLabelContent.length === 2) {
+      const splitLabelTrimmed = _.trim(splitLabelContent[0])
+      labelMap[splitLabelTrimmed] = splitLabelContent[1]
+      if (splitLabelTrimmed === 'release') {
+        //get label for release name
+        foundReleaseLabel = true
+        const releaseName = _.trim(splitLabelContent[1])
+        name = _.replace(name, `${releaseName}-`, '')
+        name = _.replace(name, releaseName, '')
+
+        if (name.length === 0) {
+          // release name is used as name, need to strip generated suffix
+          name = removeReleaseGeneratedSuffix(savedName)
+        }
       }
     }
   })
@@ -868,6 +789,14 @@ export const getNameWithoutChartRelease = (
     }
   }
 
+  if (
+    !foundReleaseLabel &&
+    kind !== 'helmrelease' &&
+    labelMap['app.kubernetes.io/name']
+  ) {
+    name = labelMap['app.kubernetes.io/name']
+  }
+
   return name
 }
 
@@ -920,8 +849,17 @@ export const getNameWithoutPodHash = relatedKind => {
     const values = R.split('=')(resLabel)
     if (values.length === 2) {
       const labelKey = values[0].trim()
-      if (labelKey === 'pod-template-hash') {
+      if (
+        labelKey === 'pod-template-hash' ||
+        labelKey === 'controller-revision-hash' ||
+        labelKey === 'controller.kubernetes.io/hash'
+      ) {
         podHash = values[1].trim()
+        if (podHash.indexOf('-') > -1) {
+          // for hashes that include prefix, always take last section
+          const hashValues = R.split('-')(podHash)
+          podHash = hashValues[hashValues.length - 1]
+        }
         nameNoHash = R.replace(`-${podHash}`, '')(nameNoHash)
       }
       if (
@@ -935,8 +873,8 @@ export const getNameWithoutPodHash = relatedKind => {
       }
     }
   })
-
-  return { nameNoHash, deployableName }
+  //return podHash as well, it will be used to map pods with parent resource
+  return { nameNoHash, deployableName, podHash }
 }
 
 //add deployed object to the matching resource in the map
@@ -951,6 +889,16 @@ const addResourceToModel = (
   _.set(resourceMapObject, `specs.${kind}Model`, kindModel)
 }
 
+// reduce complexity for code smell
+export const checkNotOrObjects = (obj1, obj2) => {
+  return !obj1 || !obj2
+}
+
+// reduce complexity for code smell
+export const checkAndObjects = (obj1, obj2) => {
+  return obj1 && obj2
+}
+
 //creates a map with all related kinds for this app, not only pod types
 export const setupResourceModel = (
   list,
@@ -958,114 +906,157 @@ export const setupResourceModel = (
   isClusterGrouped,
   isHelmRelease
 ) => {
-  if (list && resourceMap) {
-    list.forEach(kindArray => {
+  if (checkNotOrObjects(list, resourceMap)) {
+    return resourceMap
+  }
+  const podIndex = _.findIndex(list, ['kind', 'pod'])
+  //move pods last in the list to be processed after all resources producing pods have been processed
+  //we want to add the pods to the map by using the pod hash
+  let orderedList =
+    podIndex === -1
+      ? list
+      : _.concat(
+        _.slice(list, 0, podIndex),
+        _.slice(list, podIndex + 1),
+        list[podIndex]
+      )
+  orderedList = _.pullAllBy(
+    orderedList,
+    [{ kind: 'deployable' }, { kind: 'cluster' }],
+    'kind'
+  )
+
+  orderedList.forEach(kindArray => {
+    const relatedKindList = R.pathOr([], ['items'])(kindArray)
+    relatedKindList.forEach(relatedKind => {
+      const kind = relatedKind.kind
+
+      //look for pod template hash and remove it from the name if there
+      const { nameNoHash, deployableName, podHash } = getNameWithoutPodHash(
+        relatedKind
+      )
+
+      //for routes generated by Ingress, remove route name hash
+      const nameNoHashIngressPod = getRouteNameWithoutIngressHash(
+        relatedKind,
+        nameNoHash
+      )
+
+      const nameWithoutChartRelease = getNameWithoutChartRelease(
+        relatedKind,
+        nameNoHashIngressPod,
+        isHelmRelease
+      )
+
+      let name = computeResourceName(
+        relatedKind,
+        deployableName,
+        nameWithoutChartRelease,
+        isClusterGrouped
+      )
+
       if (
-        R.contains(_.get(kindArray, 'kind', ''), [
-          'cluster',
-          'placementrule',
-          'channel',
-          'deployable'
-        ])
+        kind === 'subscription' &&
+        _.get(relatedKind, 'cluster', '') === LOCAL_HUB_NAME &&
+        _.get(relatedKind, 'localPlacement', '') === 'true' &&
+        _.endsWith(name, '-local')
       ) {
-        return //ignore these type of resources
+        //match local hub subscription after removing -local suffix
+        name = _.trimEnd(name, '-local')
       }
 
-      const relatedKindList = R.pathOr([], ['items'])(kindArray)
+      const existingResourceMapKey = getExistingResourceMapKey(
+        resourceMap,
+        name,
+        relatedKind
+      )
+      if (checkAndObjects(podHash, existingResourceMapKey)) {
+        //update resource map key with podHash if the resource has a pod hash ( deployment, replicaset, deploymentconig, etc )
+        //this is going to be used to link pods with this parent resource
+        resourceMap[`pod-${podHash}`] = resourceMap[existingResourceMapKey]
+      } else if (checkAndObjects(deployableName, existingResourceMapKey)) {
+        resourceMap[`pod-deploymentconfig-${deployableName}`] =
+          resourceMap[existingResourceMapKey]
+      }
 
-      relatedKindList.forEach(relatedKind => {
-        const kind = relatedKind.kind
+      let resourceMapForObject = resourceMap[name]
+      if (!resourceMapForObject && kind === 'pod' && podHash) {
+        //just found a pod object, try to map it to the parent resource using the podHash
+        resourceMapForObject = resourceMap[`pod-${podHash}`]
+      } else if (!resourceMapForObject && kind === 'pod' && deployableName) {
+        resourceMapForObject =
+          resourceMap[`pod-deploymentconfig-${deployableName}`]
+      }
 
-        //look for pod template hash and remove it from the name if there
-        const { nameNoHash, deployableName } = getNameWithoutPodHash(
-          relatedKind
-        )
-
-        const nameWithoutChartRelease = getNameWithoutChartRelease(
+      if (resourceMapForObject) {
+        addResourceToModel(
+          resourceMapForObject,
+          kind,
           relatedKind,
-          nameNoHash,
-          isHelmRelease
+          nameWithoutChartRelease
         )
-
-        let name = computeResourceName(
-          relatedKind,
-          deployableName,
-          nameWithoutChartRelease,
-          isClusterGrouped
-        )
-
-        if (
-          kind === 'subscription' &&
-          _.get(relatedKind, 'cluster', '') === LOCAL_HUB_NAME &&
-          _.get(relatedKind, 'localPlacement', '') === 'true' &&
-          _.endsWith(name, '-local')
-        ) {
-          //match local hub subscription after removing -local suffix
-          name = _.trimEnd(name, '-local')
-        }
-
-        let resourceMapForObject = resourceMap[name]
-        if (resourceMapForObject) {
-          addResourceToModel(
-            resourceMapForObject,
-            kind,
-            relatedKind,
-            nameWithoutChartRelease
-          )
-        } else {
-          //get resource by looking at the cluster grouping
-          Object.keys(resourceMap).forEach(key => {
-            resourceMapForObject = resourceMap[key]
-            if (
-              _.startsWith(key, name) &&
-              _.includes(
-                _.get(
-                  resourceMapForObject,
-                  'clusters.specs.sortedClusterNames',
-                  [LOCAL_HUB_NAME] // if no cluster found for this resource, this could be a local deployment
-                ),
-                _.get(relatedKind, 'cluster')
-              )
-            ) {
-              addResourceToModel(
+      } else {
+        //get resource by looking at the cluster grouping
+        Object.keys(resourceMap).forEach(key => {
+          resourceMapForObject = resourceMap[key]
+          if (
+            _.startsWith(key, name) &&
+            _.includes(
+              _.get(
                 resourceMapForObject,
-                kind,
-                relatedKind,
-                nameWithoutChartRelease
-              )
-            }
-          })
-        }
-      })
+                'clusters.specs.sortedClusterNames',
+                [LOCAL_HUB_NAME] // if no cluster found for this resource, this could be a local deployment
+              ),
+              _.get(relatedKind, 'cluster')
+            )
+          ) {
+            addResourceToModel(
+              resourceMapForObject,
+              kind,
+              relatedKind,
+              nameWithoutChartRelease
+            )
+          }
+        })
+      }
     })
-  }
+  })
+
+  // need to preprocess and sync up podStatusMap for controllerrevision to parent
+  syncControllerRevisionPodStatusMap(resourceMap)
+
   return resourceMap
 }
 
 //show resource deployed status on the remote clusters
 //for resources not producing pods
-export const setResourceDeployStatus = (node, details) => {
+export const setResourceDeployStatus = (node, details, activeFilters) => {
+  const isDeployable = isDeployableResource(node)
+  const { resourceStatuses = new Set() } = activeFilters
+  const activeFilterCodes = getActiveFilterCodes(resourceStatuses)
   if (
     nodeMustHavePods(node) ||
-    R.contains(node.type, [
-      'application',
-      'placements',
-      'cluster',
-      'subscription',
-      'package'
-    ])
+    node.type === 'package' ||
+    (!isDeployable &&
+      R.contains(node.type, [
+        'application',
+        'placements',
+        'cluster',
+        'subscription'
+      ]))
   ) {
     //resource with pods info is processed separately
-    //ignore packages
+    //ignore packages or any resources from the above list not defined as a deployable
     return details
   }
   const name = _.get(node, metadataName, '')
   const channel = _.get(node, 'specs.raw.spec.channel', '')
-  const resourceName = channel.length > 0 ? `${channel}-${name}` : name
+  const resourceName =
+    !isDeployable && channel.length > 0 ? `${channel}-${name}` : name
 
   const clusterNames = R.split(',', getClusterName(node.id))
   const resourceMap = _.get(node, `specs.${node.type}Model`, {})
-  const clusterObjs = _.get(node, 'clusters.specs.clusters', [])
+  const clusterObjs = _.get(node, clusterObjsPath, [])
   const onlineClusters = getOnlineClusters(clusterNames, clusterObjs)
 
   if (_.get(node, 'type', '') === 'ansiblejob') {
@@ -1089,7 +1080,7 @@ export const setResourceDeployStatus = (node, details) => {
       type: 'spacer'
     })
     clusterName = R.trim(clusterName)
-    const res = resourceMap[`${resourceName}-${clusterName}`]
+    let res = resourceMap[`${resourceName}-${clusterName}`]
 
     if (_.get(node, 'type', '') !== 'ansiblejob') {
       const deployedKey = res
@@ -1097,14 +1088,33 @@ export const setResourceDeployStatus = (node, details) => {
         : node.type === 'namespace' ? notDeployedNSStr : notDeployedStr
       const statusStr =
         deployedKey === deployedStr || deployedKey === deployedNSStr
-          ? 'checkmark'
-          : 'pending'
+          ? checkmarkStatus
+          : pendingStatus
 
-      details.push({
-        labelValue: clusterName,
-        value: deployedKey,
-        status: statusStr
-      })
+      let addItemToDetails = false
+      if (resourceStatuses.size > 0) {
+        if (
+          (statusStr === checkmarkStatus &&
+            activeFilterCodes.has(checkmarkCode)) ||
+          (statusStr === pendingStatus &&
+            (activeFilterCodes.has(pendingCode) ||
+              activeFilterCodes.has(warningCode)))
+        ) {
+          addItemToDetails = true
+        }
+      } else {
+        addItemToDetails = true
+      }
+
+      if (addItemToDetails) {
+        details.push({
+          labelValue: clusterName,
+          value: deployedKey,
+          status: statusStr
+        })
+      } else {
+        res = null
+      }
     }
 
     if (res) {
@@ -1114,6 +1124,11 @@ export const setResourceDeployStatus = (node, details) => {
       //for service
       addNodeServiceLocation(node, clusterName, details)
 
+      // add apiversion if not exist
+      if (!res.apiversion) {
+        _.assign(res, { apiversion: _.get(node, 'specs.raw.apiVersion') })
+      }
+
       details.push({
         type: 'link',
         value: {
@@ -1121,7 +1136,7 @@ export const setResourceDeployStatus = (node, details) => {
           data: {
             action: showResourceYaml,
             cluster: res.cluster,
-            selfLink: res.selfLink
+            editLink: createEditLink(res)
           }
         },
         indent: true
@@ -1136,30 +1151,16 @@ export const setResourceDeployStatus = (node, details) => {
   return details
 }
 
-export const getOnlineClusters = (clusterNames, clusterObjs) => {
-  const onlineClusters = []
-
-  clusterNames.forEach(clsName => {
-    if (clsName.trim() === LOCAL_HUB_NAME) {
-      onlineClusters.push(clsName)
-      return
-    }
-    for (let i = 0; i < clusterObjs.length; i++) {
-      const clusterObjName = _.get(clusterObjs[i], 'metadata.name')
-      if (clusterObjName === clsName.trim()) {
-        if (clusterObjs[i].status === 'ok') {
-          onlineClusters.push(clsName)
-        }
-        break
-      }
-    }
-  })
-
-  return onlineClusters
-}
-
 //show resource deployed status for resources producing pods
-export const setPodDeployStatus = (node, updatedNode, details) => {
+export const setPodDeployStatus = (
+  node,
+  updatedNode,
+  details,
+  activeFilters
+) => {
+  const { resourceStatuses = new Set() } = activeFilters
+  const activeFilterCodes = getActiveFilterCodes(resourceStatuses)
+
   if (!nodeMustHavePods(node)) {
     return details //process only resources with pods
   }
@@ -1177,7 +1178,7 @@ export const setPodDeployStatus = (node, updatedNode, details) => {
   const podDataPerCluster = {} //pod details list for each cluster name
 
   const clusterNames = R.split(',', getClusterName(node.id))
-  const clusterObjs = _.get(node, 'clusters.specs.clusters', [])
+  const clusterObjs = _.get(node, clusterObjsPath, [])
   const onlineClusters = getOnlineClusters(clusterNames, clusterObjs)
 
   onlineClusters.forEach(clusterName => {
@@ -1192,24 +1193,43 @@ export const setPodDeployStatus = (node, updatedNode, details) => {
     let statusStr
     switch (pulse) {
     case 'red':
-      statusStr = 'failure'
+      statusStr = failureStatus
       break
     case 'yellow':
-      statusStr = 'warning'
+      statusStr = warningStatus
       break
     case 'orange':
-      statusStr = 'pending'
+      statusStr = pendingStatus
       break
     default:
-      statusStr = 'checkmark'
+      statusStr = checkmarkStatus
       break
     }
 
-    details.push({
-      labelValue: clusterName,
-      value: valueStr,
-      status: statusStr
-    })
+    let addItemToDetails = false
+    if (resourceStatuses.size > 0) {
+      const pendingOrWanrning =
+        statusStr === pendingStatus || statusStr === warningStatus
+      if (
+        (statusStr === checkmarkStatus &&
+          activeFilterCodes.has(checkmarkCode)) ||
+        (statusStr === warningStatus && activeFilterCodes.has(warningCode)) ||
+        (pendingOrWanrning && activeFilterCodes.has(pendingCode)) ||
+        (statusStr === failureStatus && activeFilterCodes.has(failureCode))
+      ) {
+        addItemToDetails = true
+      }
+    } else {
+      addItemToDetails = true
+    }
+
+    if (addItemToDetails) {
+      details.push({
+        labelValue: clusterName,
+        value: valueStr,
+        status: statusStr
+      })
+    }
 
     podDataPerCluster[clusterName] = []
   })
@@ -1226,49 +1246,65 @@ export const setPodDeployStatus = (node, updatedNode, details) => {
     const clusterDetails = podDataPerCluster[cluster]
     if (clusterDetails) {
       const statusStr = podError
-        ? 'failure'
-        : podWarning ? 'warning' : 'checkmark'
+        ? failureStatus
+        : podWarning ? warningStatus : checkmarkStatus
 
-      addDetails(clusterDetails, [
-        {
-          labelKey: 'resource.pod',
-          value: pod.name
-        },
-        {
-          labelKey: 'resource.status',
-          value: status,
-          status: statusStr
+      let addPodDetails = false
+      if (resourceStatuses.size > 0) {
+        if (
+          (statusStr === failureStatus && activeFilterCodes.has(failureCode)) ||
+          (statusStr === warningStatus && activeFilterCodes.has(warningCode)) ||
+          (statusStr === checkmarkStatus &&
+            activeFilterCodes.has(checkmarkCode))
+        ) {
+          addPodDetails = true
         }
-      ])
-      clusterDetails.push({
-        type: 'link',
-        value: {
-          label: msgs.get('props.show.log'),
-          data: {
-            action: showResourceYaml,
-            cluster: pod.cluster,
-            selfLink: pod.selfLink
+      } else {
+        addPodDetails = true
+      }
+
+      if (addPodDetails) {
+        addDetails(clusterDetails, [
+          {
+            labelKey: 'resource.pod',
+            value: pod.name
+          },
+          {
+            labelKey: 'resource.status',
+            value: status,
+            status: statusStr
           }
-        },
-        indent: true
-      })
-      addDetails(clusterDetails, [
-        {
-          labelKey: 'resource.restarts',
-          value: `${restarts}`
-        },
-        {
-          labelKey: 'resource.hostip',
-          value: `${hostIP}, ${podIP}`
-        },
-        {
-          labelKey: 'resource.created',
-          value: getAge(startedAt)
-        }
-      ])
-      clusterDetails.push({
-        type: 'spacer'
-      })
+        ])
+        clusterDetails.push({
+          type: 'link',
+          value: {
+            label: msgs.get('props.show.log'),
+            data: {
+              action: showResourceYaml,
+              cluster: pod.cluster,
+              editLink: createEditLink(pod)
+            }
+          },
+          indent: true
+        })
+        addDetails(clusterDetails, [
+          {
+            labelKey: 'resource.restarts',
+            value: `${restarts}`
+          },
+          {
+            labelKey: 'resource.hostip',
+            value: `${hostIP}, ${podIP}`
+          },
+          {
+            labelKey: 'resource.created',
+            value: getAge(startedAt)
+          }
+        ])
+        clusterDetails.push({
+          type: 'spacer'
+        })
+      }
     }
   })
 
@@ -1307,9 +1343,15 @@ const setClusterWindowStatus = (windowStatusArray, subscription, details) => {
   })
 }
 
-export const setSubscriptionDeployStatus = (node, details) => {
-  if (R.pathOr('', ['type'])(node) !== 'subscription') {
-    return details
+export const setSubscriptionDeployStatus = (node, details, activeFilters) => {
+  const { resourceStatuses = new Set() } = activeFilters
+  const activeFilterCodes = getActiveFilterCodes(resourceStatuses)
+  //check if this is a subscription created from the app deployable
+  if (
+    R.pathOr('', ['type'])(node) !== 'subscription' ||
+    isDeployableResource(node)
+  ) {
+    return details //ignore subscriptions defined from deployables or any other types
   }
   const timeWindow = _.get(node, 'specs.raw.spec.timewindow.windowtype')
   const timezone = _.get(node, 'specs.raw.spec.timewindow.location', 'NA')
@@ -1372,7 +1414,15 @@ export const setSubscriptionDeployStatus = (node, details) => {
   })
 
   let localSubscriptionFailed = false
-  const resourceMap = _.get(node, 'specs.subscriptionModel', {})
+  let resourceMap = _.get(node, 'specs.subscriptionModel', {})
+  const filteredResourceMap = filterSubscriptionObject(
+    resourceMap,
+    activeFilterCodes
+  )
+
+  if (resourceStatuses.size > 0) {
+    resourceMap = filteredResourceMap
+  }
   Object.values(resourceMap).forEach(subscription => {
     const isLocalFailedSubscription =
       subscription._hubClusterResource &&
@@ -1393,10 +1443,10 @@ export const setSubscriptionDeployStatus = (node, details) => {
         'Fail',
         R.pathOr('', ['status'])(subscription)
       )
-        ? 'failure'
+        ? failureStatus
         : R.pathOr(null, ['status'])(subscription) === null
-          ? 'warning'
-          : 'checkmark'
+          ? warningStatus
+          : checkmarkStatus
 
       //if subscription has not status show an error message
       const emptyStatusErrorMsg = subscription._hubClusterResource
@@ -1427,7 +1477,7 @@ export const setSubscriptionDeployStatus = (node, details) => {
           data: {
             action: showResourceYaml,
             cluster: subscription.cluster,
-            selfLink: subscription.selfLink
+            editLink: createEditLink(subscription)
           }
         },
         indent: true
@@ -1441,17 +1491,18 @@ export const setSubscriptionDeployStatus = (node, details) => {
 
   //show missing remote placement error only if local subscription is successful and is not local placement
   if (
-    Object.keys(resourceMap).length === 1 &&
+    Object.keys(resourceMap).length === 0 &&
     !localSubscriptionFailed &&
-    !isLocalPlacementSubs
+    !isLocalPlacementSubs &&
+    resourceStatuses.size === 0
   ) {
     //no remote subscriptions
     details.push({
       labelValue: msgs.get('resource.subscription.remote'),
       value: msgs.get('resource.subscription.placed.error', [node.namespace]),
-      status: 'failure'
+      status: failureStatus
     })
-    const ruleSearchLink = `/multicloud/search?filters={"textsearch":"kind%3Aplacementrule%20namespace%3A${
+    const ruleSearchLink = `/search?filters={"textsearch":"kind%3Aplacementrule%20namespace%3A${
       node.namespace
     }%20cluster%3A${LOCAL_HUB_NAME}"}`
     details.push({
@@ -1484,7 +1535,7 @@ export const setPlacementRuleDeployStatus = (node, details) => {
     details.push({
       labelValue: msgs.get('resource.rule.clusters.error.label'),
       value: msgs.get('resource.rule.placed.error.msg'),
-      status: 'failure'
+      status: failureStatus
     })
   }
 
@@ -1511,15 +1562,15 @@ export const setApplicationDeployStatus = (node, details) => {
   })
 
   //show error if no channel, meaning there is no linked subscription
-  if (!_.get(node, 'specs.channels')) {
+  if (!isDeployableResource(node) && !_.get(node, 'specs.channels')) {
     const appNS = _.get(node, metadataNamespace, 'NA')
 
     details.push({
       labelKey: 'resource.rule.clusters.error.label',
       value: msgs.get('resource.application.error.msg', [appNS]),
-      status: 'failure'
+      status: failureStatus
     })
-    const subscrSearchLink = `/multicloud/search?filters={"textsearch":"kind%3Asubscription%20namespace%3A${appNS}%20cluster%3A${LOCAL_HUB_NAME}"}`
+    const subscrSearchLink = `/search?filters={"textsearch":"kind%3Asubscription%20namespace%3A${appNS}%20cluster%3A${LOCAL_HUB_NAME}"}`
     details.push({
       type: 'link',
       value: {
@@ -1541,9 +1592,30 @@ export const addNodeOCPRouteLocationForCluster = (
   typeObject,
   details
 ) => {
+  const rules = R.pathOr([], ['specs', 'raw', 'spec', 'rules'])(node)
+  if (rules.length > 1) {
+    //we don't know how to process more then one hosts if the Ingress generates more than one route
+    return details
+  }
+
   const clustersList = R.pathOr([], ['clusters', 'specs', 'clusters'])(node)
   let hostName = R.pathOr(undefined, ['specs', 'raw', 'spec', 'host'])(node)
 
+  if (typeObject && _.get(node, 'name', '') !== _.get(typeObject, 'name', '')) {
+    //if route name on remote cluster doesn't match the main route name ( generated from Ingress ), show the name here
+    //this is to cover the scenario when the Ingress object defines multiple routes,
+    //so it generates multiple Route objects on the same cluster
+    addPropertyToList(
+      details,
+      getNodePropery(typeObject, ['name'], 'spec.route.cluster.name')
+    )
+  }
+
+  if (!hostName && rules.length === 1) {
+    //check rules path, for route generated by Ingress
+    hostName = _.get(rules[0], 'host')
+  }
+
   if (clustersList.length === 0 && !hostName) {
     // this is a local app deploy, check hostname in ingress
     const ingress = R.pathOr([], ['specs', 'raw', 'spec', 'ingress'])(node)
@@ -1704,6 +1776,7 @@ export const addNodeInfoPerCluster = (
 ) => {
   const resourceName = _.get(node, metadataName, '')
   const resourceMap = _.get(node, `specs.${node.type}Model`, {})
+
   const locationDetails = []
   const typeObject = resourceMap[`${resourceName}-${clusterName}`]
 
@@ -1736,17 +1809,14 @@ export const addNodeServiceLocationForCluster = (node, typeObject, details) => {
 export const processResourceActionLink = resource => {
   let targetLink = ''
   const linkPath = R.pathOr('', ['action'])(resource)
-  const { name, namespace, cluster, selfLink, kind } = resource
+  const { name, namespace, editLink, kind } = resource
   const nsData = namespace ? ` namespace:${namespace}` : ''
   switch (linkPath) {
-  case 'show_pod_log':
-    targetLink = `/multicloud/details/${cluster}/api/v1/namespaces/${namespace}/pods/${name}/logs`
-    break
   case showResourceYaml:
-    targetLink = `/multicloud/details/${cluster}${selfLink}`
+    targetLink = editLink
     break
   case 'show_search':
-    targetLink = `/multicloud/search?filters={"textsearch":"kind:${kind}${nsData} name:${name}"}`
+    targetLink = `/search?filters={"textsearch":"kind:${kind}${nsData} name:${name}"}`
     break
   default:
     targetLink = R.pathOr('', ['targetLink'])(resource)
@@ -1763,12 +1833,3 @@ export const getType = (type, locale) => {
     ? nlsType
     : _.capitalize(_.startCase(type))
 }
-
-export const getClusterHost = consoleURL => {
-  const consoleURLInstance = new URL(consoleURL)
-  const ocpIdx = consoleURL ? consoleURLInstance.host.indexOf('.') : -1
-  if (ocpIdx < 0) {
-    return ''
-  }
-  return consoleURLInstance.host.substr(ocpIdx + 1)
-}
