@@ -712,7 +712,8 @@ module.exports = {
 	"80.0.3987.163": [
 		"8.2.1",
 		"8.2.2",
-		"8.2.3"
+		"8.2.3",
+		"8.5.3"
 	],
 	"80.0.3987.165": [
 		"8.2.4",
@@ -1018,7 +1019,9 @@ module.exports = {
 	],
 	"87.0.4280.27": [
 		"11.0.0-beta.16",
-		"11.0.0-beta.17"
+		"11.0.0-beta.17",
+		"11.0.0-beta.18",
+		"11.0.0-beta.19"
 	],
 	"85.0.4156.0": [
 		"11.0.0-nightly.20200529"
@@ -1071,5 +1074,9 @@ module.exports = {
 	"88.0.4292.0": [
 		"12.0.0-nightly.20201023",
 		"12.0.0-nightly.20201026"
+	],
+	"88.0.4306.0": [
+		"12.0.0-nightly.20201030",
+		"12.0.0-nightly.20201102"
 	]
 };
\ No newline at end of file
