@@ -1,6 +1,7 @@
 /** Keep alphabetically sorted */
 export * from './AboutModal';
 export * from './Accordion';
+export * from './ActionList';
 export * from './Alert';
 export * from './AlertGroup';
 export * from './ApplicationLauncher';
@@ -12,16 +13,19 @@ export * from './Banner';
 export * from './Brand';
 export * from './Breadcrumb';
 export * from './Button';
+export * from './CalendarMonth';
 export * from './Card';
 export * from './Checkbox';
 export * from './ChipGroup';
 export * from './ClipboardCopy';
 export * from './ContextSelector';
 export * from './DataList';
+export * from './DatePicker';
 export * from './DescriptionList';
 export * from './Divider';
 export * from './Drawer';
 export * from './Dropdown';
+export * from './DualListSelector';
 export * from './EmptyState';
 export * from './ExpandableSection';
 export * from './FileUpload';
@@ -29,10 +33,12 @@ export * from './Form';
 export * from './FormSelect';
 export * from './Hint';
 export * from './InputGroup';
+export * from './JumpLinks';
 export * from './Label';
 export * from './LabelGroup';
 export * from './List';
 export * from './LoginPage';
+export * from './Menu';
 export * from './Modal';
 export * from './Nav';
 export * from './NotificationBadge';
@@ -50,16 +56,17 @@ export * from './SimpleList';
 export * from './Skeleton';
 export * from './SkipToContent';
 export * from './Spinner';
-export * from './Splitter';
 export * from './Switch';
 export * from './Tabs';
 export * from './Text';
 export * from './TextArea';
 export * from './TextInput';
 export * from './Tile';
+export * from './TimePicker';
 export * from './Title';
 export * from './ToggleGroup';
 export * from './Toolbar';
 export * from './Tooltip';
+export * from './Touchspin';
 export * from './TreeView';
 export * from './Wizard';
