@@ -1,6 +1,6 @@
-var _curry1 = require('./internal/_curry1');
-var sum = require('./sum');
+var _curry1 = /*#__PURE__*/require('./internal/_curry1');
 
+var sum = /*#__PURE__*/require('./sum');
 
 /**
  * Returns the mean of the given list of numbers.
@@ -12,11 +12,15 @@ var sum = require('./sum');
  * @sig [Number] -> Number
  * @param {Array} list
  * @return {Number}
+ * @see R.median
  * @example
  *
  *      R.mean([2, 7, 9]); //=> 6
  *      R.mean([]); //=> NaN
  */
-module.exports = _curry1(function mean(list) {
+
+
+var mean = /*#__PURE__*/_curry1(function mean(list) {
   return sum(list) / list.length;
 });
+module.exports = mean;
\ No newline at end of file
